@@ -1,9 +1,10 @@
 """
 Base data types which are extended with concrete OpenId data types in :mod:`simple_openid_connect.data`
 """
+
 import abc
 import logging
-from typing import Any, List, Literal, Type, TypeVar
+from typing import List, Literal, Type, TypeVar
 
 from cryptojwt import JWK, JWS
 from furl import Query, furl
@@ -31,7 +32,7 @@ class OpenidBaseModel(BaseModel, metaclass=abc.ABCMeta):
 
         """
         query = Query()
-        query.set(self.dict(exclude_defaults=True))
+        query.set(self.model_dump(exclude_defaults=True))
         return query.encode()  # type: ignore # because furl has no typedefs, but we know what this returns
 
     def encode_url(self, url: str) -> str:
@@ -43,7 +44,7 @@ class OpenidBaseModel(BaseModel, metaclass=abc.ABCMeta):
         it should never need to generate responses.
         """
         url_parsed = furl(url)
-        url_parsed.args.update(self.dict(exclude_defaults=True))
+        url_parsed.args.update(self.model_dump(exclude_defaults=True))
         return url_parsed.tostr()  # type: ignore # because furl has no typedefs, but we know what this returns
 
     @classmethod
@@ -53,7 +54,7 @@ class OpenidBaseModel(BaseModel, metaclass=abc.ABCMeta):
         """
         query = Query(s)
         one_value_params = {key: query.params[key] for key in query.params.keys()}
-        return cls.parse_obj(one_value_params)
+        return cls.model_validate(one_value_params)
 
     @classmethod
     def parse_url(
@@ -89,11 +90,11 @@ class OpenidBaseModel(BaseModel, metaclass=abc.ABCMeta):
     @classmethod
     def parse_jwt(cls: Type[Self], value: str, signing_keys: List[JWK]) -> Self:
         """
-        Parse received data that is encoded as a signed Json-Web-Token (JWT).
+        Parse received data that is encoded as a signed Json-Web-Signature (JWS).
 
         :param value: The encoded JWT
         :param signing_keys: List of keys one of which has been used to sign the JWT
         """
         verifier = JWS()
         msg = verifier.verify_compact(value, signing_keys)
-        return cls.parse_obj(msg)
+        return cls.model_validate(msg)
