@@ -7,7 +7,7 @@ import logging
 import time
 from typing import Any, Callable, List, Literal, Mapping, Optional, Union
 
-from pydantic import ConfigDict, Field, model_validator
+from pydantic import ConfigDict, Field, model_validator, AliasChoices
 
 from simple_openid_connect.base_data import OpenidBaseModel
 from simple_openid_connect.utils import validate_that
@@ -206,6 +206,7 @@ class IdToken(OpenidBaseModel):
         min_iat: float = 0,
         validate_acr: Union[Callable[[str], None], None] = None,
         min_auth_time: float = 0,
+        expect_self_azp: bool = True,
     ) -> None:
         """
         Validate this ID-Token with external data for consistency
@@ -226,6 +227,8 @@ class IdToken(OpenidBaseModel):
             It basically means that if the user was authenticated very far in the past and reused their session, the time at which the original authentication took place must be greater than this value.
             This is only validated if the :data:`IdToken.auth_time` is present in the token.
             This value is a posix timestamp and default to 0 which allows arbitrarily old `auth_time` dates.
+        :param expect_self_azp: Dictate to the validation that when an :data:`IdToken.azp` claim is present in the token, that claim should match this client's own client_id.
+            If you know and accept that the token has been issued to a different client, set this value to ``False``.
 
         :raises ValidationError: if the validation fails
         """
@@ -246,8 +249,8 @@ class IdToken(OpenidBaseModel):
                 "ID-Token's audience does not contain own client_id",
             )
             validate_that(
-                all(i in extra_trusted_audiences for i in self.aud),
-                "Not all of the ID-Token's audience are trusted",
+                all((i in extra_trusted_audiences or i == client_id) for i in self.aud),
+                "Not all of the ID-Token's audiences are trusted",
             )
 
         # 4. validate that an azp claim is present if required
@@ -258,7 +261,7 @@ class IdToken(OpenidBaseModel):
             )
 
         # 5. validate azp claim value
-        if self.azp is not None:
+        if self.azp is not None and expect_self_azp:
             validate_that(
                 self.azp == client_id,
                 "The ID-Token was not issued to this client (azp claim mismatch)",
@@ -297,14 +300,12 @@ class JwtAccessToken(OpenidBaseModel):
 
     The specification defines a profile for issuing access tokens in JSON Web Token (JWT) format.
     Authorization servers from different vendors may leverage this profile to issue access tokens in an interoperable
-    manner but they are in no way required to do so.
+    manner, but they are in no way required to do so.
 
     .. note::
 
-        While the RFC defines some fields to be required, some vendors issue tokens that look like they conform to the RFC
-        but in fact do not because some required fields are missing.
-        To allow usage of these tokens even though they do not strictly conform to the RFC, almost all fields are marked
-        optional.
+       Some Identity Providers encode an ``azp`` claim (similar to :data:`IdToken.azp`) instead of :data:`client_id <JwtAccessToken.client_id>`.
+       Since both claims semantically contain the same information, tokens with an ``azp`` claim are normalized to contain ``client_id`` instead.
     """
 
     model_config = ConfigDict(extra="allow", frozen=True)
@@ -315,19 +316,19 @@ class JwtAccessToken(OpenidBaseModel):
     exp: int
     "The 'exp' (expiration time) claim identifies the expiration time on or after which the JWT MUST NOT be accepted for processing. The processing of the 'exp' claim requires that the current date/time MUST be before the expiration date/time listed in the 'exp' claim. Implementers MAY provide for some small leeway, usually no more than a few minutes, to account for clock skew. Its value MUST be a number containing a NumericDate value."
 
-    aud: Optional[Union[str, List[str]]] = None
+    aud: Union[str, List[str]]
     "The 'aud' (audience) claim identifies the recipients that the JWT is intended for. Each principal intended to process the JWT MUST identify itself with a value in the audience claim. If the principal processing the claim does not identify itself with a value in the 'aud' claim when this claim is present, then the JWT MUST be rejected. In the general case, the 'aud' value is an array of case-sensitive strings, each containing a StringOrURI value. In the special case when the JWT has one audience, the 'aud' value MAY be a single case-sensitive string containing a StringOrURI value. The interpretation of audience values is generally application specific."
 
-    sub: Optional[str] = None
+    sub: str
     "Subject Identifier A locally unique and never reassigned identifier within the Issuer for the End-User, which is intended to be consumed by the Client, e.g., 24400320 or AItOawmwtWwcT0k51BayewNvutrJUqsvl6qs7A4 It MUST NOT exceed 255 ASCII characters in length The sub value is a case sensitive string."
 
-    client_id: Optional[str] = None
-    "The client_id claim carries the client identifier of the OpenId client that requested the token."
+    client_id: str = Field(validation_alias=AliasChoices("client_id", "azp"))
+    "The client_id claim carries the client identifier of the OpenId client that requested the token. If a token contains an ``azp`` claim, that claim is deserialized into this field."
 
-    iat: Optional[int] = None
+    iat: int
     "As defined in Section 4.1.6 of [RFC7519]. This claim identifies the time at which the JWT access token was issued."
 
-    jti: Optional[str] = None
+    jti: str
     "Unique identifier for the token."
 
     auth_time: Optional[int] = None
@@ -350,27 +351,28 @@ class JwtAccessToken(OpenidBaseModel):
             Should usually be :data:`ProviderMetadata.issuer`.
         :param client_id: The client id of this client
         """
+        # implemented according to https://www.rfc-editor.org/rfc/rfc9068#name-validating-jwt-access-token
+
         # validate issuer
         validate_that(
             self.iss == issuer,
-            "The access token was issued from unexpected issuer",
+            "The access token was issued from an unexpected issuer",
         )
 
         # validate expiry
         validate_that(self.exp > time.time(), "The access token is expired")
 
         # validate audience
-        if self.aud is not None:
-            if isinstance(self.aud, str):
-                validate_that(
-                    self.aud == client_id,
-                    "The access tokens audience does not contain own client_id",
-                )
-            elif isinstance(self.aud, list):
-                validate_that(
-                    client_id in self.aud,
-                    "The access tokens audience does not contain own client_id",
-                )
+        if isinstance(self.aud, str):
+            validate_that(
+                self.aud == client_id,
+                "The access tokens audience does not contain own client_id",
+            )
+        elif isinstance(self.aud, list):
+            validate_that(
+                client_id in self.aud,
+                "The access tokens audience does not contain own client_id",
+            )
 
 
 class UserinfoRequest(OpenidBaseModel):
