@@ -1,6 +1,7 @@
 """
 Exceptions that are raised at various parts of this library.
 """
+
 from typing import TYPE_CHECKING, Any
 
 if TYPE_CHECKING:
@@ -41,6 +42,11 @@ class AuthenticationFailedError(Exception):
     def __init__(self, error: "AuthenticationErrorResponse"):
         super().__init__(error)
 
+    @property
+    def error(self) -> "AuthenticationErrorResponse":
+        value = self.args[0]  # type: AuthenticationErrorResponse
+        return value
+
 
 class ValidationError(AssertionError):
     """
@@ -49,3 +55,8 @@ class ValidationError(AssertionError):
 
     def __init__(self, msg: str):
         super().__init__(msg)
+
+    @property
+    def msg(self) -> str:
+        value = self.args[0]  # type: str
+        return value
