@@ -35,10 +35,10 @@ def fetch_userinfo(
 
     if not utils.is_application_json(response.headers["Content-Type"]):
         raise OpenidProtocolError(
-            f"userinfo request was responded with invalid Content-Type", response
+            "userinfo request was responded with invalid Content-Type", response
         )
 
     if response.status_code == 200:
-        return UserinfoSuccessResponse.parse_raw(response.content)
+        return UserinfoSuccessResponse.model_validate_json(response.content)
     else:
-        return UserinfoErrorResponse.parse_raw(response.content)
+        return UserinfoErrorResponse.model_validate_json(response.content)
