@@ -1,6 +1,5 @@
 import json
 
-import pytest
 from django.shortcuts import resolve_url
 
 
@@ -10,12 +9,20 @@ def test_unauth_access(client):
     assert response.headers["WWW-Authenticate"] == "Bearer"
 
 
-@pytest.mark.interactive
-def test_invalid_token_text(client, live_server, mafiasi_identity_settings):
+def test_invalid_token_text(
+    client,
+    dummy_provider_settings,
+    dummy_provider_config,
+    dummy_token_introspection_response,
+    response_mock,
+):
+    # act
     response = client.get(
         resolve_url("access-token-protected-view"),
-        HTTP_Authorization="Bearer foobar123",
+        HTTP_Authorization="Bearer invalid-token",
     )
+
+    # assert
     assert response.status_code == 401
     assert response.headers["WWW-Authenticate"] == "Bearer"
     assert (
@@ -24,13 +31,20 @@ def test_invalid_token_text(client, live_server, mafiasi_identity_settings):
     )
 
 
-@pytest.mark.interactive
-def test_invalid_token_json(client, mafiasi_identity_settings):
+def test_invalid_token_json(
+    client,
+    dummy_provider_settings,
+    dummy_provider_config,
+    dummy_token_introspection_response,
+):
+    # act
     response = client.get(
         resolve_url("access-token-protected-view"),
-        HTTP_Authorization="Bearer foobar123",
+        HTTP_Authorization="Bearer access_token.invalid",
         HTTP_Accept="application/json",
     )
+
+    # assert
     assert response.status_code == 401
     assert response.headers["WWW-Authenticate"] == "Bearer"
     assert response.headers["Content-Type"] == "application/json"
