@@ -2,14 +2,13 @@ from base64 import b64encode
 
 import pytest
 import requests
-from responses import RequestsMock
 
 from simple_openid_connect.client_authentication import ClientSecretBasicAuth, NoneAuth
 
 
 @pytest.fixture
-def mock_empty_response(mocked_responses: RequestsMock):
-    mocked_responses.get(url="https://example.com")
+def mock_empty_response(response_mock):
+    response_mock.get(url="https://example.com")
 
 
 def test_none_auth(mock_empty_response):
